@@ -278,9 +278,10 @@ class Droplet(BaseAPI):
         if data:
             self.id = data['droplet']['id']
 
-        self.action_ids = []
-        for id in data[u'droplet'][u'action_ids']:
-            self.action_ids.append(id)
+        if data[u'droplet'].has_key(u"action_ids"):
+            self.action_ids = []
+            for id in data[u'droplet'][u'action_ids']:
+                self.action_ids.append(id)
 
     def get_events(self):
         """
@@ -294,10 +295,14 @@ class Droplet(BaseAPI):
             Returns a list of Action objects
             This actions can be used to check the droplet's status
         """
+        answer = self.get_data(
+            "droplets/%s/actions" % self.id,
+            type="GET"
+        )
+
         actions = []
-        for action_id in self.action_ids:
-            action = Action()
-            action.id = action_id
+        for action_dict in answer['actions']:
+            action = Action(**action_dict)
             action.token = self.token
             action.droplet_id = self.id
             action.load()
